@@ -257,7 +257,8 @@ class Background:
         tickperx = params['tickperx']
         marker = params['marker']
         rotation = params['rotation']
-        vmin,vmax = np.percentile(tmpdata,minmax[0]),np.percentile(tmpdata,minmax[1])
+        m = np.isfinite(tmpdata)
+        vmin,vmax = np.percentile(tmpdata[m],minmax[0]),np.percentile(tmpdata[m],minmax[1])
         xg,yg,ww = self.bbox['bbox']['XG'],self.bbox['bbox']['YG'],self.bbox['bbox']['WW']
         bb0x,bb1x = self.bbox['bbox']['BBX']
         bb0y,bb1y = self.bbox['bbox']['BBY']
